HIRISE_api.preprocessing.Encoding — HIRISE_api documentation

# HIRISE_api.preprocessing.Encoding

Functions

`create_encoded_samples_dataframe`(folder_path) | Function that uses the autoencoder to encode the samples and return an encoded samples dataframe to the user based on latent dimensions input by the user
`plot_autoencoder_results`(encoder, decoder, ...) | Function that plots the original and reconstructed images form the autoencoder results
`test_batchs`(encoder, decoder, device, ...) | Function that is used to test the Convolutional Autoencoder and return the mean loss, averaged over all input batches.
`train_CAE`(encoder, decoder, device, ...) | Function that is used to train using a single batch input into the autoencoder.
`train_batchs`(encoder, decoder, device, ...) | Function that is used to train the Convolutional Autoencoder and return the mean loss, averaged over all input batches.
`transfer_learning_encoding`(folder_path[, ...]) | The Transfer learning function takes in the folder path of the images to

Classes

`CAEDecoder`(encoded_space_dim, fc2_input_dim) | Class that supports functions needed to define the architecture and forward functions of the decoder in the Convolutional Autoencoder
`CAEEncoder`(encoded_space_dim, fc2_input_dim) | Class that supports functions needed to define the architecture and forward functions of the encoder in the Convolutional Autoencoder